@@ -5,10 +5,11 @@ use warnings;
 
 use Text::CSV;
 use IO::File;
+use IO::Scalar;
 
 use vars qw/$VERSION/;
 
-$VERSION = 1.02;
+$VERSION = 1.03;
 
 sub new {
   my $class = shift;
@@ -22,41 +23,25 @@ sub load {
   my %default = ( binary => 1 );
   %opt = (%default, %opt);
 
-  unless (defined $opt{file} || defined $opt{filehandle} || defined $opt{string}) {
-    die "Need either a file, filehandle or string to work with";
-  }
-
+  my $io;
   if (defined $opt{filehandle}) {
-    my $io = $opt{filehandle};
+    $io = $opt{filehandle};
     delete $opt{filehandle};
-    return _from_handle($io,\%opt);
   }
   elsif (defined $opt{file}) {
-    my $io = new IO::File;
+    $io = new IO::File;
     open($io, "<$opt{file}") || die "Could not open $opt{file} $!";
     delete $opt{file};
     return _from_handle($io,\%opt);
   }
-  else {
-    my @data  = split /\n/, $opt{string};
+  elsif (defined $opt{string}) {
+    $io = IO::Scalar->new(\$opt{string});
     delete $opt{string};
-
-    my $csv   = Text::CSV->new(\%opt);
-    $csv->parse(shift @data);
-
-    my @names = $csv->fields();
-
-    my @results;
-
-    for my $line (@data) {
-      $csv->parse($line);
-      my %hash;
-      @hash{@names} = $csv->fields();
-      push @results, \%hash;
-    }
-
-    return \@results;
   }
+  else {
+    die "Need either a file, filehandle or string to work with";
+  }
+  return _from_handle($io,\%opt);
 }
 
 sub create {
@@ -136,7 +121,7 @@ Text::CSV::Slurp - Text::CSV::Slurp - convert CSV into an array of hashes, or an
 
 =head1 VERSION
 
-version 1.02
+version 1.03
 
 =head1 SUMMARY
 
@@ -194,10 +179,10 @@ arguments are passed to L<Text::CSV> except for C<field_order>.
 
 =head3 field_order
 
-C<field_order> which is used to determine the fields and order in which they 
+C<field_order> which is used to determine the fields and order in which they
 appear in the CSV. For example:
 
- my $csv = Text::CSV::Slurp->create( input => \@array_of_hashes, 
+ my $csv = Text::CSV::Slurp->create( input => \@array_of_hashes,
                                      field_order => ['one','three','two'] );
 
 If field_order is not supplied then the sorted keys of the first hash in the
@@ -228,6 +213,7 @@ L<Spreadsheet::Read>
 =head1 THANKS
 
 To Kyle Albritton for suggesting and testing the L<create> method
+To Tomas Pokorny for the L<IO::Scalar> patch for the L<load> method
 
 =head1 AUTHOR
 
@@ -235,7 +221,7 @@ BABF <babf@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by BABF.
+This software is copyright (c) 2016 by BABF.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
